OC.L10N.register(
    "news",
    {
    "Download" : "Բեռնել",
    "Close" : "Փակել",
    "Folder name" : "Պանակի անուն",
    "Username" : "Օգտանուն",
    "Password" : "Գաղտնաբառ",
    "New folder" : "Նոր պանակ",
    "Credentials" : "Credentials",
    "Move" : "Տեղափոխել",
    "Share" : "Կիսվել",
    "Settings" : "Կարգավորումներ",
    "Rename" : "Վերանվանել",
    "Delete" : "հեռացնել",
    "Folder" : "Պանակ",
    "Refresh" : "Թարմացնել"
},
"nplurals=2; plural=(n != 1);");
